package com.halo.halojuhesdk.core.base;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;

/**
 * Created by dream on 2016/11/10.
 */

public abstract class AbstractTask implements Runnable {
    protected Runnable mRunnable;

    protected Handler mHandler = null;

    protected boolean mGoBack = false;

    private boolean isPrepared = false;

    protected Context mContext;

    protected ITaskListener mListener;
    /**
     * 当前任务执行结果状态机
     */
    protected boolean mExcuteSucc;

    /**
     * 为当前task做预处理
     *
     * @return 是否继续执行
     */
    protected abstract boolean preExecute();

    /**
     * task处理后收尾工作private
     */
    protected abstract void onExcute();

    /**
     * task处理事件方法
     */
    protected void postExcute() {
        if (mGoBack && mRunnable != null) {
            mHandler.post(mRunnable);
        }
    }

    /**
     * 加载方式
     *
     * @return
     */
    public abstract LaunchMode getLaunchMode();

    /**
     * 当前Task区分标识
     *
     * @return
     */
    public abstract String getName();

    /**
     * 外部传入Runnable做同线程返回
     * @param runable
     */
    public void setRunable(Runnable runable) {
        this.mRunnable = runable;
    }

    /**
     * 外部传入监听对象做同线程返回
     * @param
     */
    public void setListener(ITaskListener listener) {
        this.mListener = listener;
    }

    /**
     * 构造方法
     * @param context
     * @param needGoBack  是否需要返回原有线程
     */
    public AbstractTask(Context context , boolean needGoBack) {
        this.mContext = context;
        mGoBack = needGoBack;
        if (mGoBack) {
            if(Looper.myLooper() == null){
                isPrepared = true;
                Looper.prepare();
            }
            mHandler = new Handler();

        }
    }

    /**
     * 当所有执行完之后调用
     * 运行在Create线程
     */
    public void afterExcute(){
        if(isPrepared){
            Looper.loop();
        }
    }
    @Override
    public String toString() {
        return getName();
    }

    @Override
    public boolean equals(Object obj) {
        return toString().equals(obj.toString());
    }

    @Override
    public void run() {
        if (preExecute()) {
            onExcute();
            postExcute();
        }
    }


}
