package com.halo.halojuhesdk.core.common.utils;

import static com.halo.halojuhesdk.core.base.utils.LogUtils.LEVEL_ERROR;
import static com.halo.halojuhesdk.core.base.utils.LogUtils.LEVEL_NONE;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.Display;
import android.view.WindowManager;

import androidx.annotation.NonNull;

import com.halo.halojuhesdk.core.base.utils.LogUtils;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

/**
 * @author Feng Zhanao
 * @date 2018/7/4
 * @description
 */
public class MyUtils {
    private static Context mContext;
    private static final String SP_KEY_NAME =  "huanju_fusion_info";
    private static Handler mUiHandler;

    public static Context getContext() {
        return mContext;
    }

    public static synchronized void init(Context cx) {
        mContext = cx.getApplicationContext();
        if (mUiHandler == null) {
            mUiHandler = new Handler(mContext.getMainLooper());
        }
    }

    public static synchronized void init(Context cx ,boolean isDebug) {
        mContext = cx.getApplicationContext();
        if (mUiHandler == null) {
            mUiHandler = new Handler(mContext.getMainLooper());
        }
        LogUtils.setDeBugModel(isDebug ? LEVEL_ERROR : LEVEL_NONE);
    }

    public static void runInMainThread(Runnable runnable) {
        if (isRunInMainThread()) {
            runnable.run();
        } else {
            post(runnable);
        }

    }

    public static SharedPreferences getSp() {
        Context context = getContext();
        if (context != null) {
            return context.getSharedPreferences(SP_KEY_NAME, 0);
        }
        return null;
    }
    public static void putLong(String name ,long value){
        getSp().edit().putLong(name,value).apply();
    }
    public static long getLong(String name,long value){
       return getSp().getLong(name, value);
    }

    public static boolean isRunInMainThread() {
        return Thread.currentThread().getId() == Looper.getMainLooper().getThread().getId();
    }

    public static void post(Runnable runnable) {
        getUiHandler().post(runnable);
    }

    public synchronized static Handler getUiHandler() {
        return mUiHandler;
    }
    public static Resources getResources() {
        return getContext().getResources();
    }
    public static boolean isPortrait() {

        Configuration mConfiguration = getContext().getResources()
                .getConfiguration(); // 获取设置的配置信息
        int ori = mConfiguration.orientation; // 获取屏幕方向

        if (ori == Configuration.ORIENTATION_LANDSCAPE) {
            // 横屏
            return false;
        } else if (ori == Configuration.ORIENTATION_PORTRAIT) {
            // 竖屏
            return true;
        }
        return false;
    }

    /**
     * 获取屏幕尺寸信息
     *
     * @return
     */
    @SuppressWarnings("deprecation")
    public static int[] getScreenSize(Context cx, boolean matchScreen) {
        try {
            if (cx == null) {
                cx = getContext();
            }
            WindowManager wm = (WindowManager) cx.getSystemService(
                    Context.WINDOW_SERVICE);
            Display display = wm.getDefaultDisplay();
            if (!matchScreen || MyUtils.isPortrait()) {
                return new int[]{display.getWidth(), display.getHeight()};
            } else {
                return new int[]{display.getHeight(), display.getWidth()};
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return new int[]{0, 0};
    }

    public static int getScreenWidthDip(Context context) {
        return px2dip(context, getScreenSize(context, true)[0]);
    }

    public static int getScreenHeightDip(Context context) {
        return px2dip(context, getScreenSize(context, true)[1]);
    }

    public static int px2dip(Context context, float pxValue) {
        final float scale = context.getResources().getDisplayMetrics().density;
        return (int) (pxValue / scale + 0.5f);
    }

    public static boolean WifiConnected(Context context) {
        ConnectivityManager connectivityManager = (ConnectivityManager)context.getSystemService(Context.CONNECTIVITY_SERVICE);
        NetworkInfo activeNetInfo = connectivityManager.getActiveNetworkInfo();
        if (activeNetInfo != null && activeNetInfo.getType() == ConnectivityManager.TYPE_WIFI) {
            return true;
        }
        return false;
    }

    @NonNull
    public static String md5(String string) {
        if (TextUtils.isEmpty(string)) {
            return "";
        }
        MessageDigest md5 = null;
        try {
            md5 = MessageDigest.getInstance("MD5");
            byte[] bytes = md5.digest(string.getBytes());
            StringBuilder result = new StringBuilder();
            for (byte b : bytes) {
                String temp = Integer.toHexString(b & 0xff);
                if (temp.length() == 1) {
                    temp = "0" + temp;
                }
                result.append(temp);
            }
            return result.toString();
        } catch (NoSuchAlgorithmException e) {
            e.printStackTrace();
        }
        return "";
    }
}
