package com.halo.halojuhesdk.core.request;

import com.halo.halojuhesdk.core.base.LaunchMode;
import com.halo.halojuhesdk.core.base.ReqType;
import com.halo.halojuhesdk.core.base.net.AbstractNetTask;
import com.halo.halojuhesdk.core.base.utils.KeyUtil;
import com.halo.halojuhesdk.core.base.utils.LogUtils;
import com.halo.halojuhesdk.core.base.utils.SystemUtils;
import com.halo.halojuhesdk.core.common.utils.Config;
import com.halo.halojuhesdk.core.common.utils.HttpUrlSettings;
import com.halo.halojuhesdk.core.common.utils.MyUtils;

import org.json.JSONObject;

import java.io.OutputStream;
import java.math.BigDecimal;
import java.net.HttpURLConnection;
import java.text.DecimalFormat;

/**
 * 统一请求类，如果需要post请求，请继承该类复写getEntity方法,和getReqType
 */

public class StatisTask extends AbstractNetTask {

    private SlotBean mBean;
    private String mStepName;
    private String mAction;
    private String mReqId;
    private String mErrorMsg;

    public StatisTask(SlotBean bean, String stepName, String action, String reqId, String errorMsg) {
        super(MyUtils.getContext(), false);
        mBean = bean;
        mStepName = stepName;
        mAction = action;
        mReqId = reqId;
        mErrorMsg = errorMsg;
    }

    @Override
    public String getURL() {
        return HttpUrlSettings.getStatisUrl(mReqId);
    }

    /**
     * post请求
     *
     * @param outputStream
     */
    @Override
    protected void getEntity(OutputStream outputStream) {
        try {
            if (outputStream != null) {
                JSONObject jsonObject = new JSONObject();
                jsonObject.put("appId", Config.mAppId);
                jsonObject.put("slotId", mBean.slotId);
                jsonObject.put("adAppId", mBean.appId);
                jsonObject.put("adSlotId", mBean.adSlotId);
                jsonObject.put("stepName", mStepName);
                if (mBean != null && mBean.getOp() > 0) {
                    BigDecimal bigDecimal = BigDecimal.valueOf(mBean.getOp());
                    String opStr = KeyUtil.encryptCurrentAES(SystemUtils.formatCurrentData(), String.valueOf(bigDecimal));
//                    opStr = String.valueOf(mBean.getOp());
                    jsonObject.put("op", opStr);
                } else {
                    jsonObject.put("op", "0");
                }
                if (mBean != null && mBean.getEp() > 0) {
                    BigDecimal bigDecimal = BigDecimal.valueOf(mBean.getEp());
                    String epStr = KeyUtil.encryptCurrentAES(SystemUtils.formatCurrentData(), String.valueOf(bigDecimal));
//                    epStr = String.valueOf(mBean.getEp());
                    jsonObject.put("ep", epStr);
                } else {
                    jsonObject.put("ep", "0");
                }
//                jsonObject.put("reqId", mReqId);
//                jsonObject.put("adid", HlStatisManager.getInstance().getConfigReqId());
                if (mStepName.equals(HlStatisManager.STEPNAME_REPORT)) {
                    jsonObject.put("report", mAction);
//                    LogUtils.e("==StatisProcessor :" + jsonObject + "===" + mStepName);
                } else if (mStepName.equals(HlStatisManager.STEPNAME_ERROR)) {
                    jsonObject.put("msg", mErrorMsg);
                }
                jsonObject.put("cur","USD");
//                LogUtils.e("====action===" + mAction +"===jsonObject===" + jsonObject);
                outputStream.write(jsonObject.toString().getBytes());
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override
    protected void onAddHeaders(HttpURLConnection connection) {
        connection.setRequestProperty("Content-Type", "application/json");
    }

    @Override
    protected ReqType getReqType() {
        return ReqType.Post;
    }

    @Override
    public LaunchMode getLaunchMode() {
        return LaunchMode.addnew;
    }

    @Override
    public String getName() {
        return "StatisTask";
    }
}
